==> HMpTy-1.5.0.tar.gz: HMpTy-1.5.0/README.md <==
# HMpTy

<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/HMpTy)](https://pypi.org/project/HMpTy/)  
[![](https://img.shields.io/pypi/v/HMpTy)](https://pypi.org/project/HMpTy/)  
[![](https://img.shields.io/github/license/thespacedoctor/HMpTy)](https://github.com/thespacedoctor/HMpTy)  
[![](https://img.shields.io/pypi/dm/HMpTy)](https://pypi.org/project/HMpTy/)  

<!-- STATUS BADGES -->  

[![](http://167.99.90.204:8080/buildStatus/icon?job=HMpTy%2Fmaster&subject=build%20master)](http://167.99.90.204:8080/blue/organizations/jenkins/HMpTy/activity?branch=master)  
[![](http://167.99.90.204:8080/buildStatus/icon?job=HMpTy%2Fdevelop&subject=build%20dev)](http://167.99.90.204:8080/blue/organizations/jenkins/HMpTy/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/HMpTy@master/coverage.svg)](https://raw.githack.com/thespacedoctor/HMpTy/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/HMpTy/badge/?version=master)](https://HMpTy.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/thespacedoctor/HMpTy/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/HMpTy/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*Generate Hierarchical Triangular Mesh (HTM) IDs, crossmatch sets of sky-coordinates and more*.

![](http://i.imgur.com/5GG4979.png)

Documentation for HMpTy is hosted by [Read the Docs](https://HMpTy.readthedocs.io/en/master/) (
[development version](https://HMpTy.readthedocs.io/en/develop/) and [master version](https://HMpTy.readthedocs.io/en/master/)). The code lives on [github](https://github.com/thespacedoctor/HMpTy). Please report any issues you find [here](https://github.com/thespacedoctor/HMpTy/issues).

## Features

*

==> HMpTy-1.5.2.tar.gz: HMpTy-1.5.2/README.md <==
# HMpTy

<!-- INFO BADGES -->  

[![](https://img.shields.io/pypi/pyversions/HMpTy)](https://pypi.org/project/HMpTy/)  
[![](https://img.shields.io/pypi/v/HMpTy)](https://pypi.org/project/HMpTy/)  
[![](https://img.shields.io/github/license/thespacedoctor/HMpTy)](https://github.com/thespacedoctor/HMpTy)  
[![](https://img.shields.io/pypi/dm/HMpTy)](https://pypi.org/project/HMpTy/)  

<!-- STATUS BADGES -->  

[![](http://167.99.90.204:8080/buildStatus/icon?job=HMpTy%2Fmaster&subject=build%20master)](http://167.99.90.204:8080/blue/organizations/jenkins/HMpTy/activity?branch=master)  
[![](http://167.99.90.204:8080/buildStatus/icon?job=HMpTy%2Fdevelop&subject=build%20dev)](http://167.99.90.204:8080/blue/organizations/jenkins/HMpTy/activity?branch=develop)  
[![](https://cdn.jsdelivr.net/gh/thespacedoctor/HMpTy@master/coverage.svg)](https://raw.githack.com/thespacedoctor/HMpTy/master/htmlcov/index.html)  
[![](https://readthedocs.org/projects/hmpty/badge/?version=master)](https://HMpTy.readthedocs.io/en/master/)  
[![](https://img.shields.io/github/issues/thespacedoctor/HMpTy/type:%20bug?label=bug%20issues)](https://github.com/thespacedoctor/HMpTy/issues?q=is%3Aissue+is%3Aopen+label%3A%22type%3A+bug%22+)  

*Generate Hierarchical Triangular Mesh (HTM) IDs, crossmatch sets of sky-coordinates and more*.

![](http://i.imgur.com/5GG4979.png)

Documentation for HMpTy is hosted by [Read the Docs](https://HMpTy.readthedocs.io/en/master/) (
[development version](https://HMpTy.readthedocs.io/en/develop/) and [master version](https://HMpTy.readthedocs.io/en/master/)). The code lives on [github](https://github.com/thespacedoctor/HMpTy). Please report any issues you find [here](https://github.com/thespacedoctor/HMpTy/issues).

## Features

*
